@@ -167,6 +167,9 @@ struct _GWeatherInfoPrivate {
 #define RADIANS_TO_DEGREES(rad)		((rad) * 180. / M_PI)
 #define RADIANS_TO_HOURS(rad)		((rad) * 12. / M_PI)
 
+GWEATHER_EXTERN
+char           *_radians_to_degrees_str (gdouble radians);
+
 /*
  * Planetary Mean Orbit and their progressions from J2000 are based on the
  * values in http://ssd.jpl.nasa.gov/txt/aprx_pos_planets.pdf
