@@ -46,7 +46,7 @@ typedef enum { /*< flags, underscore_name=gweather_provider >*/
     GWEATHER_PROVIDER_YAHOO = 1 << 3,
     GWEATHER_PROVIDER_YR_NO = 1 << 4,
     GWEATHER_PROVIDER_OWM = 1 << 5,
-    GWEATHER_PROVIDER_ALL = 31
+    GWEATHER_PROVIDER_ALL = (GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_IWIN | GWEATHER_PROVIDER_YAHOO | GWEATHER_PROVIDER_YR_NO | GWEATHER_PROVIDER_OWM)
 } GWeatherProvider;
 
 typedef struct _GWeatherInfo GWeatherInfo;
