@@ -26,6 +26,7 @@
 #include <gweather-version.h>
 #include "gweather-location.h"
 #include "gweather-weather.h"
+#include "gweather-private.h"
 
 extern void _gweather_location_reset_world (void);
 
@@ -419,7 +420,13 @@ test_metar_weather_stations (void)
     msg = soup_message_new ("GET", METAR_SOURCES);
     session = soup_session_new ();
     soup_session_send_message (session, msg);
-    g_assert (SOUP_STATUS_IS_SUCCESSFUL (msg->status_code));
+    if (msg->status_code == SOUP_STATUS_SSL_FAILED) {
+        g_test_message ("SSL/TLS failure, please check your glib-networking installation");
+        g_test_failed ();
+        return;
+    }
+    g_assert_cmpint (msg->status_code, >=, 200);
+    g_assert_cmpint (msg->status_code, <, 300);
     g_object_unref (session);
     g_assert_nonnull (msg->response_body);
 
@@ -758,6 +765,20 @@ test_weather_loop_use_after_free (void)
     g_main_loop_unref (loop);
 }
 
+static void
+test_radians_to_degrees_str (void)
+{
+    char long_version[G_ASCII_DTOSTR_BUF_SIZE];
+    g_autofree char *short_version = NULL;
+    double coord = 1.260765526077;
+
+    g_ascii_dtostr (long_version, G_ASCII_DTOSTR_BUF_SIZE, RADIANS_TO_DEGREES (coord));
+    short_version = _radians_to_degrees_str (coord);
+
+    g_assert_cmpint (strlen (long_version), >, strlen (short_version));
+    g_assert_cmpstr (short_version, ==, "72.2365");
+}
+
 static void
 log_handler (const char *log_domain, GLogLevelFlags log_level, const char *message, gpointer user_data)
 {
@@ -780,6 +801,7 @@ main (int argc, char *argv[])
 		  FALSE);
 	set_gsettings ();
 
+	g_test_add_func ("/weather/radians-to-degrees_str", test_radians_to_degrees_str);
 	g_test_add_func ("/weather/named-timezones", test_named_timezones);
 	g_test_add_func ("/weather/named-timezones-deserialized", test_named_timezones_deserialized);
 	g_test_add_func ("/weather/no-code-serialize", test_no_code_serialize);
